define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ovaj kv.",
	"field-quarter-short-relative+1": "sljedeći kv.",
	"field-tue-relative+-1": "prošli utorak",
	"field-year": "godina",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"field-minute": "minuta",
	"field-month-narrow-relative+-1": "prošli mj.",
	"field-tue-narrow-relative+0": "ovaj uto.",
	"field-tue-narrow-relative+1": "sljedeći uto.",
	"field-thu-short-relative+0": "ovaj čet.",
	"field-day-short-relative+-1": "jučer",
	"field-thu-short-relative+1": "sljedeći čet.",
	"field-day-relative+0": "danas",
	"field-day-short-relative+-2": "prekjučer",
	"field-day-relative+1": "sutra",
	"field-week-narrow-relative+0": "ovaj tj.",
	"field-day-relative+2": "prekosutra",
	"field-week-narrow-relative+1": "sljedeći tj.",
	"field-wed-narrow-relative+-1": "prošla sri.",
	"field-year-narrow": "g.",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "ove g.",
	"field-tue-relative+0": "ovaj utorak",
	"field-year-narrow-relative+1": "sljedeće g.",
	"field-tue-relative+1": "sljedeći utorak",
	"field-weekdayOfMonth": "radni dan u mjesecu",
	"field-second-short": "s",
	"field-weekdayOfMonth-narrow": "r. dan u mj.",
	"field-week-relative+0": "ovaj tjedan",
	"field-month-relative+0": "ovaj mjesec",
	"field-week-relative+1": "sljedeći tjedan",
	"field-month-relative+1": "sljedeći mjesec",
	"field-sun-narrow-relative+0": "ova ned.",
	"field-mon-short-relative+0": "ovaj pon.",
	"field-sun-narrow-relative+1": "sljedeća ned.",
	"field-mon-short-relative+1": "sljedeći pon.",
	"field-second-relative+0": "sad",
	"field-weekOfMonth": "tjedan u mjesecu",
	"field-month-short": "mj.",
	"field-day": "dan",
	"field-dayOfYear-short": "dan u god.",
	"field-year-relative+-1": "prošle godine",
	"field-sat-short-relative+-1": "prošla sub.",
	"field-hour-relative+0": "ovaj sat",
	"field-wed-relative+-1": "prošla srijeda",
	"field-sat-narrow-relative+-1": "prošla sub.",
	"field-second": "sekunda",
	"dateFormat-long": "d. M. y.",
	"field-quarter": "kvartal",
	"field-week-short": "tj.",
	"field-day-narrow-relative+0": "danas",
	"field-day-narrow-relative+1": "sutra",
	"field-day-narrow-relative+2": "prekosutra",
	"field-tue-short-relative+0": "ovaj uto.",
	"field-tue-short-relative+1": "sljedeći uto.",
	"field-month-short-relative+-1": "prošli mj.",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"field-month": "mjesec",
	"field-day-narrow": "d.",
	"field-minute-short": "min",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "ova sub.",
	"field-sat-short-relative+1": "sljedeća sub.",
	"dateFormat-medium": "d. M. y.",
	"field-second-narrow": "s",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"field-day-narrow-relative+-1": "jučer",
	"field-year-short": "g.",
	"field-day-narrow-relative+-2": "prekjučer",
	"field-quarter-relative+-1": "prošli kvartal",
	"field-dayperiod-narrow": "AM/PM",
	"field-week-narrow-relative+-1": "prošli tj.",
	"field-dayOfYear": "dan u godini",
	"field-sat-relative+-1": "prošla subota",
	"field-hour": "sat",
	"dateFormat-full": "E, d. M. y.",
	"field-month-relative+-1": "prošli mjesec",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "ova sub.",
	"field-fri-relative+0": "ovaj petak",
	"field-sat-narrow-relative+1": "sljedeća sub.",
	"field-fri-relative+1": "sljedeći petak",
	"field-month-narrow-relative+0": "ovaj mj.",
	"field-month-narrow-relative+1": "sljedeći mj.",
	"field-sun-short-relative+0": "ova ned.",
	"field-sun-short-relative+1": "sljedeća ned.",
	"field-week-relative+-1": "prošli tjedan",
	"field-quarter-short-relative+-1": "prošli kv.",
	"field-quarter-relative+0": "ovaj kvartal",
	"field-minute-relative+0": "ova minuta",
	"field-quarter-relative+1": "sljedeći kvartal",
	"field-wed-short-relative+-1": "prošla sri.",
	"dateFormat-short": "d. M. y.",
	"field-thu-short-relative+-1": "prošli čet.",
	"field-year-narrow-relative+-1": "prošle g.",
	"field-mon-narrow-relative+-1": "prošli pon.",
	"field-thu-narrow-relative+-1": "prošli čet.",
	"field-tue-narrow-relative+-1": "prošli uto.",
	"field-weekOfMonth-short": "tj. u mj.",
	"field-wed-short-relative+0": "ova sri.",
	"field-wed-short-relative+1": "sljedeća sri.",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-weekday": "dan u tjednu",
	"field-day-short-relative+0": "danas",
	"field-quarter-narrow-relative+0": "ovaj kv.",
	"field-sat-relative+0": "ova subota",
	"field-day-short-relative+1": "sutra",
	"field-quarter-narrow-relative+1": "sljedeći kv.",
	"field-sat-relative+1": "sljedeća subota",
	"field-day-short-relative+2": "prekosutra",
	"field-week-short-relative+0": "ovaj tj.",
	"field-week-short-relative+1": "sljedeći tj.",
	"field-dayOfYear-narrow": "dan u g.",
	"field-month-short-relative+0": "ovaj mj.",
	"field-month-short-relative+1": "sljedeći mj.",
	"field-weekdayOfMonth-short": "radni dan u mj.",
	"field-zone-narrow": "zona",
	"field-thu-narrow-relative+0": "ovaj čet.",
	"field-thu-narrow-relative+1": "sljedeći čet.",
	"field-sun-narrow-relative+-1": "prošla ned.",
	"field-mon-short-relative+-1": "prošli pon.",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-thu-relative+1": "sljedeći četvrtak",
	"field-fri-short-relative+-1": "prošli pet.",
	"field-thu-relative+-1": "prošli četvrtak",
	"field-week": "tjedan",
	"field-wed-narrow-relative+0": "ova sri.",
	"field-wed-narrow-relative+1": "sljedeća sri.",
	"field-quarter-narrow-relative+-1": "prošli kv.",
	"field-year-short-relative+0": "ove god.",
	"field-dayperiod-short": "AM/PM",
	"field-year-short-relative+1": "sljedeće god.",
	"field-fri-short-relative+0": "ovaj pet.",
	"field-fri-short-relative+1": "sljedeći pet.",
	"field-week-short-relative+-1": "prošli tj.",
	"field-hour-short": "h",
	"field-zone-short": "zona",
	"field-month-narrow": "m.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "prošli pet.",
	"field-year-relative+0": "ove godine",
	"field-year-relative+1": "sljedeće godine",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "prošli petak",
	"field-tue-short-relative+-1": "prošli uto.",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "ovaj pon.",
	"field-mon-narrow-relative+1": "sljedeći pon.",
	"field-year-short-relative+-1": "prošle god.",
	"field-zone": "vremenska zona",
	"field-weekOfMonth-narrow": "tj. u mjesecu",
	"field-weekday-narrow": "dan u tj.",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "prošla ned.",
	"field-day-relative+-1": "jučer",
	"field-day-relative+-2": "prekjučer",
	"field-weekday-short": "dan u tjed.",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"field-day-short": "d.",
	"field-week-narrow": "tj.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "ovaj pet.",
	"field-fri-narrow-relative+1": "sljedeći pet."
}
//end v1.x content
);